import niki.Welt;
import niki.Niki;

public class Rundlauf{
    public static void main(String[] args){
        Welt meineWelt = new Welt("kleineWelt.welt");
        Roboter2 meinRoboter = new Roboter2(meineWelt);

	while (true) {
		meinRoboter.vorZurWand();
		if (meinRoboter.rechtsFrei()){
			meinRoboter.rechtsKurve();
			meinRoboter.vorZurWand();
			if (meinRoboter.linksFrei()){
				meinRoboter.linksKurve();
			}else{
				break;
			}
		}else{
			break;
		}
	}
    }
}
